#ifndef KEYBOARDDECKRUNNER_H
#define KEYBOARDDECKRUNNER_H

#include "DeckRunnerUI.h"

#include <assert.h>

#include <qpushbutton.h>

namespace pitacard { namespace ui {

    template <class Selector, class FaceChooser>
    class KeyboardDeckRunnerUI : public DeckRunnerUI<Selector>
    {
    public:
	enum State
	{
	    IDLE,
	    SHOW_FRONT,
	    SHOW_BACK
	};
	
    public:
	KeyboardDeckRunnerUI(const Folder& deck,
			     QWidget* parent=0,
			     const char* name=0,
			     bool modal=FALSE,
			     QWidget::WFlags fl=0) :
	    DeckRunnerUI<Selector> (deck, parent, name, modal, fl),
	    mState (IDLE)
	    {}

    protected:
	void keyPressEvent(QKeyEvent* evt)
	    {
		switch (mState)
		{
		    case SHOW_FRONT:
			assert(haveValidCard());
			
			// mBackTextEdit->setText((*currentCard())->back().mText);
			mBackTextEdit->setText(FaceChooser::secondText(**currentCard()));
			mState = SHOW_BACK;
			repaint();
			break;
			
		    case SHOW_BACK:
			nextCard();
			assert(haveValidCard());
			//mFrontTextEdit->setText((*currentCard())->front().mText);
			mFrontTextEdit->setText(FaceChooser::firstText(**currentCard()));
			mBackTextEdit->setText("");
			mState = SHOW_FRONT;
			repaint();
			
		    default:
			break;
		}

		evt->accept();
	    }
	
	void startReview()
	    {
		assert(mState == IDLE);
		
		nextCard();
		
		if (!haveValidCard())
		{
		    mState = IDLE;
		    return;
		}
		
		mState = SHOW_FRONT;
		
		mStartButton->setEnabled(false);
		mStopButton->setEnabled(true);
		
		// mFrontTextEdit->setText((*currentCard())->front().mText);
		mFrontTextEdit->setText(FaceChooser::firstText(**currentCard()));
	    }
	
	void stopReview()
	    {
		mState = IDLE;
		
		mFrontTextEdit->setText("");
		mBackTextEdit->setText("");
		
		mStartButton->setEnabled(true);
		mStopButton->setEnabled(false);
	    }
	
    private:
	State mState;
    };
    
} }

#endif
