#include "globals.h"

#include "keyTranslator.h"
#include "ktreader.h"

#include <iostream>

#include <qapplication.h>
#include <qdir.h>
#include <qsettings.h>

namespace
{

    QFont gCardFont;
    QString xlatorDir;
    pitacard::config::XlatMap gXlatMap;
    
}

namespace pitacard { namespace config {

    void initializeConfiguration()
    {
	QSettings s;
	s.setPath( "sourceforge.net", "pitacard" );

	s.beginGroup("/pitacard");
	
	s.beginGroup("/card");
	s.beginGroup("/font");
	gCardFont =
	    QFont(s.readEntry("/family",
			      QApplication::font().family()),
		  s.readNumEntry("/pointSize",
				 QApplication::font().pointSize()),
		  s.readNumEntry("/weight",
				 QApplication::font().weight()),
		  s.readBoolEntry("/italic",
				  QApplication::font().italic()));
	s.endGroup();
	s.endGroup();


	// key-translator initialization
	xlatorDir = s.readEntry("/translatorDir",
				"/usr/local/pitacard");
	QDir dir(xlatorDir);
	QStringList xlators = dir.entryList(QDir::Files);

	if (xlators.size() < 1)
	{
	    std::cerr << "[initializeConfiguration] WARNING: No key translators found in "
		      << xlatorDir << std::endl;
	}
	
	for (QStringList::Iterator itr = xlators.begin();
	     itr != xlators.end();
	     ++itr)
	{
	    pitacard::xlat::KeyTranslator kt;
	    pitacard::xlat::Header hdr;
	    pitacard::xlat::readKeyTranslator(dir.absFilePath(*itr), kt, hdr);

	    if (hdr.find("NAME") == hdr.end())
	    {
		std::cerr << "[initializeConfiguration] ERROR: key translator "
			  << *itr << " has no NAME entry in header" << std::endl;
		continue;
	    }

	    gXlatMap[hdr["NAME"]] = kt;
	}

	s.endGroup();
    }
    
    void saveConfiguration()
    {
	QSettings s;
	s.setPath("sourceforge.net", "pitacard");

	s.beginGroup("/pitacard");
	
	s.beginGroup("/card");
	s.beginGroup("/font");
	s.writeEntry("/family", gCardFont.family());
	s.writeEntry("/pointSize", gCardFont.pointSize());
	s.writeEntry("/weight", gCardFont.weight());
	s.writeEntry("/italic", gCardFont.italic());
	s.endGroup();
	s.endGroup();

	s.writeEntry("/translatorDir", xlatorDir);

	s.endGroup();
    }
    
    
    const QFont& cardFont()
    {
	return gCardFont;
    }
    
    void setCardFont(const QFont& font)
    {
	gCardFont = font;
    }

    XlatMap& translators()
    { return gXlatMap; }
    
} }
